@@ -1,20 +1,21 @@
 # coding:utf-8
 from __future__ import print_function
 
-from volcengine.models.vod.request.request_vod_pb2 import *
 from volcengine.vod.VodService import VodService
+from volcengine.vod.models.request.request_vod_pb2 import VodGetPlayInfoRequest
 
 if __name__ == '__main__':
 
     vod_service = VodService()
     # call below method if you dont set ak and sk in $HOME/.vcloud/config
-    # vod_service.set_ak('ak')
-    # vod_service.set_sk('sk')
+    vod_service.set_ak('your ak')
+    vod_service.set_sk('your sk')
     try:
         vid = 'your vid'
         req = VodGetPlayInfoRequest()
         req.Vid = vid
-        resp = vod_service.get_play_auth_token(req)
+        expire = 60  # seconds
+        resp = vod_service.get_play_auth_token(req, expire)
     except Exception:
         raise
     else:
